@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 19's 3.14 kernel.
+# This is a kernel build script for Fedora 20's 3.19 kernel.
 #
 
 die () {
@@ -12,17 +12,17 @@ yum -y install tar wget rpm-build make gcc patch redhat-rpm-config xmlto asciido
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.14.27-100.fc19.src.rpm ]
+if [ ! -r kernel-3.19.8-100.fc20.src.rpm ]
 then
-    wget https://archives.fedoraproject.org/pub/archive/fedora/linux/updates/19/SRPMS/kernel-3.14.27-100.fc19.src.rpm || die "Can't download source package."
+    wget https://archives.fedoraproject.org/pub/archive/fedora/linux/updates/20/SRPMS/kernel-3.19.8-100.fc20.src.rpm || die "Can't download source package."
 fi
-LANG=C rpm --checksig kernel-3.14.27-100.fc19.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
-rpm -ivh kernel-3.14.27-100.fc19.src.rpm || die "Can't install source package."
+LANG=C rpm --checksig kernel-3.19.8-100.fc20.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
+rpm -ivh kernel-3.19.8-100.fc20.src.rpm || die "Can't install source package."
 
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.9-20211212.tar.gz ]
+if [ ! -r ccs-patch-1.8.9-20220222.tar.gz ]
 then
-    wget -O ccs-patch-1.8.9-20211212.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.9-20211212.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.9-20220222.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.9-20220222.tar.gz' || die "Can't download patch."
 fi
 
 cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
@@ -39,7 +39,7 @@ patch << "EOF" || die "Can't patch spec file."
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -490,7 +490,7 @@
+@@ -477,7 +477,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -48,7 +48,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2 and Redistributable, no modification permitted
  URL: http://www.kernel.org/
-@@ -945,7 +945,7 @@
+@@ -964,7 +964,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -57,27 +57,27 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -965,7 +965,7 @@
- Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
- Requires: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
+@@ -984,7 +984,7 @@
+ Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:+%{1}}\
+ Requires: kernel-uname-r = %{KVERREL}%{?1:+%{1}}\
  AutoReqProv: no\
 -%description -n kernel%{?variant}%{?1:-%{1}}-modules-extra\
 +%description -n ccs-kernel%{?variant}%{?1:-%{1}}-modules-extra\
  This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
  %{nil}
  
-@@ -1462,6 +1462,10 @@
+@@ -1527,6 +1527,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.9-20211212.tar.gz
-+patch -sp1 < patches/ccs-patch-3.14-fedora-19.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.9-20220222.tar.gz
++patch -sp1 < patches/ccs-patch-3.19-fedora-20.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1484,6 +1488,17 @@
+@@ -1551,6 +1555,17 @@
  for i in *.config
  do
    mv $i .config
